:acch4
:acco2
:acei
:acn2o
:acsf6
:aeei
:agcost
:area
:biodiversity
:cardcold
:cardheat
:climatech4cycle
:climateco2cycle
:climatedynamics
:climateforcing
:climaten2ocycle
:climateregional
:climatesf6cycle
:cooling
:cumaeei
:dead
:deadcost
:dengue
:diadead
:diasick
:drycost
:eloss
:emissions
:enter
:entercost
:extratropicalstormsdam
:extratropicalstormsdead
:forestemm
:forests
:geography
:globalpopulation
:globch4
:globn2o
:globsf6
:heating
:hurrdam
:hurrdead
:impactaggregation
:impactagriculture
:impactbiodiversity
:impactcardiovascularrespiratory
:impactcooling
:impactdeathmorbidity
:impactdiarrhoea
:impactextratropicalstorms
:impactforests
:impactheating
:impactsealevelrise
:impacttropicalstorms
:impactvectorbornediseases
:impactwaterresources
:income
:inputtemp
:landloss
:leave
:leavecost
:malaria
:mco2
:mitigationcost
:morbcost
:nospecies
:ocean
:pgrowth
:plus
:population
:populationin1
:protcost
:radforc
:regstmp
:regtmp
:resp
:scenariouncertainty
:schisto
:sea
:sloss
:socioeconomic
:species
:temp
:urbpop
:vmorb
:vsl
:vslvmorb
:water
:wetcost
:ypcgrowth

Shared Parameters

:ch4pre
:n2opre
:sf6pre
:co2pre
:nospecbase
:dbsta
:bregtmp
:plus90
:gdp90
:pop90
